@@ -16,13 +16,14 @@ import socket
 import botocore.config
 from tests import get_botocore_default_config_mapping, mock, unittest
 
-from botocore import args
+from botocore import UNSIGNED, args
 from botocore.args import PRIORITY_ORDERED_SUPPORTED_PROTOCOLS
 from botocore import exceptions
 from botocore.client import ClientEndpointBridge
 from botocore.config import Config
 from botocore.configprovider import ConfigValueStore
 from botocore.exceptions import UnsupportedServiceProtocolsError
+from botocore.credentials import Credentials
 from botocore.hooks import HierarchicalEmitter
 from botocore.model import ServiceModel
 from botocore.parsers import PROTOCOL_PARSERS
@@ -560,6 +561,45 @@ class TestCreateClientArgs(unittest.TestCase):
         ):
             self.call_compute_client_args()
 
+    def test_account_id_endpoint_mode_set_on_config_store(self):
+        self.config_store.set_config_variable(
+            'account_id_endpoint_mode', 'preferred'
+        )
+        config = self.call_get_client_args()['client_config']
+        self.assertEqual(config.account_id_endpoint_mode, 'preferred')
+
+    def test_account_id_endpoint_mode_set_on_client_config(self):
+        config = self.call_get_client_args(
+            client_config=Config(account_id_endpoint_mode='required')
+        )['client_config']
+        self.assertEqual(config.account_id_endpoint_mode, 'required')
+
+    def test_account_id_endpoint_mode_client_config_overrides_config_store(
+        self,
+    ):
+        self.config_store.set_config_variable(
+            'account_id_endpoint_mode', 'preferred'
+        )
+        config = self.call_get_client_args(
+            client_config=Config(account_id_endpoint_mode='disabled')
+        )['client_config']
+        self.assertEqual(config.account_id_endpoint_mode, 'disabled')
+
+    def test_account_id_endpoint_mode_bad_value(self):
+        with self.assertRaises(exceptions.InvalidConfigError):
+            config = Config(account_id_endpoint_mode='foo')
+            self.call_get_client_args(client_config=config)
+        self.config_store.set_config_variable(
+            'account_id_endpoint_mode', 'foo'
+        )
+        with self.assertRaises(exceptions.InvalidConfigError):
+            self.call_get_client_args()
+
+    def test_account_id_endpoint_mode_disabled_on_unsigned_request(self):
+        self._set_endpoint_bridge_resolve(signature_version=UNSIGNED)
+        config = self.call_get_client_args()['client_config']
+        self.assertEqual(config.account_id_endpoint_mode, 'disabled')
+
     def test_inject_host_prefix_default_client_config(self):
         input_config = Config()
         client_args = self.call_get_client_args(client_config=input_config)
@@ -629,6 +669,8 @@ class TestEndpointResolverBuiltins(unittest.TestCase):
             'endpoint_bridge': self.bridge,
             'client_endpoint_url': None,
             'legacy_endpoint_url': 'https://my.legacy.endpoint.com',
+            'credentials': None,
+            'account_id_endpoint_mode': 'preferred',
         }
         kwargs = {**defaults, **overrides}
         return self.args_create.compute_endpoint_resolver_builtin_defaults(
@@ -651,6 +693,8 @@ class TestEndpointResolverBuiltins(unittest.TestCase):
             bins['AWS::S3::DisableMultiRegionAccessPoints'], False
         )
         self.assertEqual(bins['SDK::Endpoint'], None)
+        self.assertEqual(bins['AWS::Auth::AccountId'], None)
+        self.assertEqual(bins['AWS::Auth::AccountIdEndpointMode'], 'preferred')
 
     def test_aws_region(self):
         bins = self.call_compute_endpoint_resolver_builtin_defaults(
@@ -800,6 +844,20 @@ class TestEndpointResolverBuiltins(unittest.TestCase):
         )
         self.assertEqual(bins['SDK::Endpoint'], None)
 
+    def test_account_id_set_with_credentials(self):
+        bins = self.call_compute_endpoint_resolver_builtin_defaults(
+            credentials=Credentials(
+                access_key='foo', secret_key='bar', account_id='baz'
+            )
+        )
+        self.assertEqual(bins['AWS::Auth::AccountId'](), 'baz')
+
+    def test_account_id_endpoint_mode_set_to_disabled(self):
+        bins = self.call_compute_endpoint_resolver_builtin_defaults(
+            account_id_endpoint_mode='disabled'
+        )
+        self.assertEqual(bins['AWS::Auth::AccountIdEndpointMode'], 'disabled')
+
 
 class TestProtocolPriorityList:
     def test_all_parsers_accounted_for(self):
